.. _GitHub: http://github.com/saxix/django-actions
.. _pip: http://pip.openplans.org/
.. _PyPI: http://pypi.python.org/
.. _virtualenv: http://virtualenv.openplans.org/
.. _chishop: https://github.com/ask/chishop
.. _DjangoPyPi2: https://github.com/popen2/djangopypi2
.. _DjangoPyPi: https://github.com/benliles/djangopypi
.. _supervisor: http://supervisord.org/
.. _haystack: http://haystacksearch.org/
.. _whoosh: https://bitbucket.org/mchaput/whoosh/wiki/Home

.. |app| replace:: PyPPi


.. _app: https://github.com/saxix/django-adminactions

